Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1395)

Unified Diff: ui/base/dragdrop/drag_utils.h

Issue 10447053: Converts remainder of ui and chrome/browser/ui/views/frame to use ImageSkia (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/web_contents/web_contents_drag_win.cc ('k') | ui/base/dragdrop/drag_utils.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ui/base/dragdrop/drag_utils.h
diff --git a/ui/base/dragdrop/drag_utils.h b/ui/base/dragdrop/drag_utils.h
index b81511d70ef1bd849dccd2f11327c82b28523631..1f009565879219b598fb005505ae9e6058222e30 100644
--- a/ui/base/dragdrop/drag_utils.h
+++ b/ui/base/dragdrop/drag_utils.h
@@ -12,10 +12,10 @@
#include "ui/base/ui_export.h"
class GURL;
-class SkBitmap;
namespace gfx {
class Canvas;
+class ImageSkia;
class Point;
class Size;
}
@@ -32,7 +32,7 @@ namespace drag_utils {
// the supplied data_object. 'file_name' can be a full path, but the directory
// portion will be truncated in the drag image.
UI_EXPORT void CreateDragImageForFile(const FilePath& file_name,
- const SkBitmap* icon,
+ const gfx::ImageSkia* icon,
ui::OSExchangeData* data_object);
// Sets the drag image on data_object from the supplied canvas. width/height
@@ -43,10 +43,10 @@ UI_EXPORT void SetDragImageOnDataObject(const gfx::Canvas& canvas,
const gfx::Point& cursor_offset,
ui::OSExchangeData* data_object);
// Sets the drag image on data_object from the supplied bitmap. width/height
// are the size of the image to use, and the offsets give the location of
// the hotspot for the drag image.
-UI_EXPORT void SetDragImageOnDataObject(const SkBitmap& bitmap,
+UI_EXPORT void SetDragImageOnDataObject(const gfx::ImageSkia& image_skia,
const gfx::Size& size,
const gfx::Point& cursor_offset,
ui::OSExchangeData* data_object);
@@ -43,10 +43,10 @@ UI_EXPORT void SetDragImageOnDataObject(const gfx::Canvas& canvas,
const gfx::Point& cursor_offset,
ui::OSExchangeData* data_object);
-// Sets the drag image on data_object from the supplied bitmap. width/height
+// Sets the drag image on data_object from the supplied ImageSkia. width/height
// are the size of the image to use, and the offsets give the location of
// the hotspot for the drag image.
« no previous file with comments | « content/browser/web_contents/web_contents_drag_win.cc ('k') | ui/base/dragdrop/drag_utils.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698